@@ -5,6 +5,7 @@
 import logging
 import os
 import numpy as np
+from argparse import ArgumentParser
 
 from datetime import datetime
 import collections 
@@ -30,7 +31,7 @@ class AutoVivification(dict):
 
 class _train(object):
     def describe(self): return self.__class__.__name__
-    def __init__(self, additiona_log, **kargs):
+    def __init__(self, **kargs):
         self.m_input_file = kargs['input_file']
         self.m_output_folder = kargs['output_folder']
         self.m_log_file = kargs['log_file']
@@ -55,7 +56,7 @@ class _train(object):
         self.m_large_pca = kargs['large_pca']
         self.m_entangle = kargs['entangle']
         self.m_entangle_gate = kargs['entangle_gate']
-        self.m_additiona_log = additiona_log
+        self.m_additiona_log = kargs['additiona_log']
         
         self.m_log_dir = {}
         self.m_log_dir['base'] = os.path.join(self.m_output_folder, 'logs_' + self.m_log_file, f'{datetime.now().strftime("%Y-%m-%d-%H-%M-%S")}-{self.m_fix_seed}-{os.uname()[1]}-bs{self.m_batch_size}-qu{self.m_nqubits}-lpca{self.m_large_pca}-train{self.m_training_size}-red{self.m_reducer}-{self.m_additiona_log}')
@@ -72,6 +73,8 @@ class _train(object):
         logging.info(f'Logger folder is: {self.m_log_dir["base"]}')
         self.config_logging()
         logging.info(f'Train option {vars(self)}')
+
+        self.m_scale_range = (-1, 1)
         
     def config_logging(self):
         log_filename = f'train{self.m_training_size}_val{self.m_val_size}_test{self.m_test_size}_bs{self.m_batch_size}.log'
@@ -221,14 +224,13 @@ class _train(object):
             logging.fatal(f'Request of Dimension Reduction dimension {self.m_nqubits} is greater than input dimension {X[0].shape[0]}.')
 
         scaler_file = f'{self.m_log_dir["model"]}/scaler.pkl'
-        scale_range = (-1, 1)
         X, y = shuffle(X, y)
         if training:
-            scaler = MinMaxScaler(feature_range=(scale_range))
+            scaler = MinMaxScaler(feature_range=(self.m_scale_range))
             scaler.fit_transform(X, y)
             X = scaler.transform(X)
             pickle.dump(scaler, open(scaler_file, 'wb'))
-            logging.info(f'Write scalar to: {scaler_file} with range {scale_range}')
+            logging.info(f'Write scalar to: {scaler_file} with range {self.m_scale_range}')
         else:
             scaler = pickle.load(open(scaler_file, 'rb'))
             logging.info(f'Load scalar from: {scaler_file}')
@@ -239,8 +241,8 @@ class _train(object):
             for column in range(X.shape[1]):
                 self.plot_input(X[y == target['1']], X[y == target['0']], column = column, name = name.format(str(column)))
             logging.info(f'Save {X.shape[1]} input columns to {name.format("*")}.pdf')
-        if self.m_plot_input_only:
-            exit(0)
+            if self.m_plot_input_only:
+                exit(0)
         else:
             logging.info(f'Save not {X.shape[1]} input columns to {name.format("*")}.pdf')
 
@@ -314,3 +316,38 @@ class _train(object):
         roc_file = f'{self.m_log_dir["result"]}/roc{len(curves)}_train{len(self.m_data.y_train)}_val{len(self.m_data.y_val)}_test{len(self.m_data.y_test)}.pdf'
         plt.savefig(roc_file, format='pdf')
         plt.clf()
+
+def add_options():
+    """Get arguments from command line."""
+    parser = ArgumentParser(description="Tensorflow Quantum model training.")
+
+    parser.add_argument('--batch-size', action='store', type=int, default=10, help='Training batch size type (default: %(default)s)')
+    parser.add_argument('--run-classical', action='store_true', default=False, help='Train classical NN as well (default: %(default)s)')
+    parser.add_argument('--entangle', action='store', type=int, default=0, help='Additinal dimension used for entanglement encoder (default: %(default)s)')
+    parser.add_argument('--entangle-gate', action='store', type=str, default='rx', choices=['rx', 'ry'], help='Additinal dimension used for entanglement encoder (default: %(default)s)')
+    parser.add_argument('--epochs', action='store', type=int, default=200, help='Training epochs (default: %(default)s)')
+    parser.add_argument('--fix-seed', action='store', type=int, default=None, help='Fix random seed (default: %(default)s)')
+    parser.add_argument('-i', '--input-file', action='store', default='data/qml/hmumu_twojet_0719.npy', help='Input data (.npz) (default: %(default)s)')
+    parser.add_argument('--large-pca', action='store_true', default=True, help='Use more events for PCA (default: %(default)s)')
+    parser.add_argument('--log-file', action='store', default='QNN', help='Directory name to store logs (default: %(default)s)')
+    parser.add_argument('--loss', action='store', default='hinge', help='Loss for QEfficientSU2NNHYB (default: %(default)s)')
+    parser.add_argument('--nqubits', action='store', type=int, default=None, required=True, help='Number of qubits / varibles (default: %(default)s)')
+    parser.add_argument('--output-folder', action='store', default='../output', help='Output folder for logs (default: %(default)s)')
+    parser.add_argument('--padding', action='store', type=float, choices=[-999, 0], default=-999, help='Padding of non-existing (default: %(default)s)')
+    parser.add_argument('--plot-input', action='store_true', default=False, help='Plotting before and after Dimension Reduction (default: %(default)s)')
+    parser.add_argument('--plot-input-only', action='store_true', default=False, help='Inspect inputs (default: %(default)s)')
+    parser.add_argument('--training-size', action='store', type=int, default=50, help='Number of events for training (default: %(default)s)')
+    parser.add_argument('--test-size', action='store', type=int, default=None, help='Number of events for test (default: %(default)s)')
+    parser.add_argument('--val-size', action='store', type=int, default=50, help='Number of events for val (default: %(default)s)')
+    parser.add_argument('--Qnetwork', type=str, choices=['QDensNN', 'QConvNN', 'QConvNNHYB', 'QZinnerCNOTNN', 'QEfficientSU2NNHYB', 'QEfficientSU2NNHYB2', 'QEfficientSU2NNQNN', 'QMNISTNN'], help='Quantum network type (default: %(default)s)')
+    
+    subparsers = parser.add_subparsers(dest='use_quple', help='Use quple encoder')
+    parser_quple = subparsers.add_parser('use_quple')
+    parser_quple.add_argument('--encoder-type', type=str, default=None, choices=['FirstOrderExpansion', 'SecondOrderExpansion'], help='Data encoder depths (default: %(default)s)')
+    parser_quple.add_argument('--ndepths', type=int, default=1, help='Data encoder depths (default: %(default)s)')
+    parser_quple.add_argument('--nlayers', type=int, default=1, help='Number of layers for quantum model (default: %(default)s)')
+
+    args = parser.parse_args()
+    options = vars(args)
+    logging.info(f'Argument option {options}')
+    return args
\ No newline at end of file
